@@ -61,7 +61,9 @@ enum CategoryId {
     /** @since 5.27 */
     ElectricalCurrentCategory,
     /** @since 5.27 */
-    ElectricalResistanceCategory
+    ElectricalResistanceCategory,
+    /** @since 5.53 */
+    PermeabilityCategory
 };
 
 enum UnitId {
@@ -91,6 +93,8 @@ enum UnitId {
     Hectoliter, Decaliter, Liter, Deciliter, Centiliter, Milliliter, Microliter, Nanoliter,
     Picoliter, Femtoliter, Attoliter, Zeptoliter, Yoctoliter, CubicFoot, CubicInch, CubicMile,
     FluidOunce, Cup, GallonUS, PintImperial,
+    /** @since 5.53 */
+    OilBarrel,
 
     // Mass
     Yottagram = 4000, Zettagram, Exagram, Petagram, Teragram, Gigagram, Megagram, Kilogram,
@@ -325,7 +329,14 @@ enum UnitId {
     /** @since 5.27 */
     Zeptoohms,
     /** @since 5.27 */
-    Yoctoohms
+    Yoctoohms,
+
+    /** @since 5.53 */
+    Darcy = 33000,
+    /** @since 5.53 */
+    MiliDarcy,
+    /** @since 5.53 */
+    PermeabilitySquareMicrometer
 };
 
 class UnitCategory;
@@ -428,7 +439,7 @@ public:
      * @param value number value
      * @param fieldWidth width of the formatted field, padded by spaces.
      *                   Positive value aligns right, negative aligns left
-     * @param format type of floating point formating, like in QString::arg
+     * @param format type of floating point formatting, like in QString::arg
      * @param precision number of digits after the decimal separator
      * @param fillChar the character used to fill up the empty places when
      *                 field width is greater than argument width
@@ -441,7 +452,7 @@ public:
      * @param value number value
      * @param fieldWidth width of the formatted field, padded by spaces.
      *                   Positive value aligns right, negative aligns left
-     * @param format type of floating point formating, like in QString::arg
+     * @param format type of floating point formatting, like in QString::arg
      * @param precision number of digits after the decimal separator
      * @param fillChar the character used to fill up the empty places when
      *                 field width is greater than argument width
